<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2006 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: DalForecasting.dal.broken.test.php 4722 2006-04-21 17:08:16Z andrew@m3.net $
*/

require_once MAX_PATH . '/lib/max/Maintenance.php';
require_once MAX_PATH . '/lib/max/Dal/Forecasting.php';
require_once MAX_PATH . '/lib/max/Table/Priority.php';

/**
 * A class for testing the non-DB specific Maintenance Channel Forecasting Engine DAL class.
 *
 * @package    MaxDal
 * @subpackage TestSuite
 * @author     Radek Maciaszek <radek@m3.net>
 */
class Dal_TestOfDalForecasting extends UnitTestCase
{

    var $errorLevel;

    /**
     * The constructor method.
     */
    function Dal_TestOfDalForecasting()
    {
        $this->UnitTestCase();
    }

    function setUp()
    {
        $this->errorLevel = error_reporting(E_ALL);
    }

    function tearDown()
    {
        error_reporting($this->errorLevel);
    }

    /**
     * Method to test the singleton method.
     *
     * Requirements:
     * Test 1: Test that only one instance of the class is created.
     */
    function testSingleton()
    {
        // Mock the MAX_DB class used in the constructor method
        Mock::generate('MAX_DB');
        $dbh = &new MockMAX_DB($this);

        // Mock the DB_QueryTool class used in the constructor method
        Mock::generate('DB_QueryTool');
        $queryBuilder = &new MockDB_QueryTool($this);

        // Partially mock the MAX_Dal_Maintenance class
        Mock::generatePartial('MAX_Dal_Forecasting',
                              'PartialMockMAX_Dal_Forecasting',
                              array('_createMaxDb', '_getQueryTool'));
        $oMaxDalMaintenance = &new PartialMockMAX_Dal_Forecasting($this);
        $oMaxDalMaintenance->setReturnReference('_createMaxDb', $dbh);
        $oMaxDalMaintenance->setReturnReference('_getQueryTool', $queryBuilder);

        // Test 1
        $first  = &$oMaxDalMaintenance->singleton();
        $second = &$oMaxDalMaintenance->singleton();
        $this->assertIdentical($first, $second);
    }

    /**
     * Method to test the singleton method.
     *
     * Requirements:
     * Test 1: Test that only one instance of the class is created.
     */
    function testSetIntervalDates()
    {
        // Mock the MAX_DB class used in the constructor method
        Mock::generate('Maintenance');
        $maintenance = &new MockMaintenance($this);
        $maintenance->expectOnce('checkIntervalDates');
        $maintenance->expectOnce('convertDateToOperationIntervalStartAndEndDates');
        $maintenance->expectOnce('convertDateToOperationIntervalID');
        $maintenance->setReturnValue('checkIntervalDates', true);

        // Partially mock the MAX_Dal_Maintenance class
        Mock::generatePartial('MAX_Dal_Forecasting',
                              'PartialMockMAX_Dal_ForecastingFor_SetIntervalDates',
                              array('_getMaintenance'));
        $oMaxDalForecasting = &new PartialMockMAX_Dal_ForecastingFor_SetIntervalDates($this);
        $oMaxDalForecasting->MAX_Dal_Common();
        $oMaxDalForecasting->setReturnReference('_getMaintenance', $maintenance);

        $oMaxDalForecasting->setIntervalDates('boo', 'foo');
        $maintenance->tally();
    }

    /**
     * Method to test the setMaintenancePriorityLastRunInfo method.
     *
     * Requirements:
     * Test 1: Test with no data in the database, ensure data is correctly stored.
     * Test 2: Test with previous test data in the database, ensure data is correctly stored.
     */
    function testSetMaintenancePriorityLastRunInfo()
    {
        TestEnv::startTransaction();
        $conf = $GLOBALS['_MAX']['CONF'];
        $dbh = &MAX_DB::singleton();
        $oMaxDalForecasting = MAX_Dal_Forecasting::singleton();

        // Test 1
        $oStartDate = new Date('2005-06-21 15:00:01');
        $oEndDate   = new Date('2005-06-21 15:01:01');
        $oUpdatedTo = new Date('2005-06-21 15:59:59');
        $ret = $oMaxDalForecasting->setMaintenanceForecastingLastRunInfo($oStartDate, $oEndDate, $oUpdatedTo);
        $this->assertTrue($ret);
        $query = "
            SELECT
                start_run,
                end_run,
                operation_interval,
                duration,
                updated_to
            FROM
                {$conf['table']['prefix']}{$conf['table']['log_maintenance_forecasting']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['start_run'], '2005-06-21 15:00:01');
        $this->assertEqual($row['end_run'], '2005-06-21 15:01:01');
        $this->assertEqual($row['operation_interval'], $conf['maintenance']['operationInterval']);
        $this->assertEqual($row['duration'], 60);
        $this->assertEqual($row['updated_to'], '2005-06-21 15:59:59');

        TestEnv::rollbackTransaction();
    }

    /**
     * Method to test the getMaintenancePriorityLastRunInfo method.
     *
     * Requirements:
     * Test 1: Test correct results are returned with no data.
     * Test 2: Test correct results are returned with single data entry.
     * Test 3: Test correct results are returned with multiple data entries.
     */
    function testGetMaintenancePriorityLastRunInfo()
    {
        TestEnv::startTransaction();
        $conf = $GLOBALS['_MAX']['CONF'];
        $dbh = &MAX_DB::singleton();
        $oMaxDalForecasting = MAX_Dal_Forecasting::singleton();

        // Test 1
        $testDate = new Date('2005-08-08 20:13:13');
        $result = $oMaxDalForecasting->getMaintenanceForecastingLastRunInfo('data_raw_ad_impression', $testDate);
        $this->assertEqual($result, $testDate);

        // Test 2
        $oStartDate = new Date('2005-06-21 15:00:01');
        $oEndDate   = new Date('2005-06-21 15:01:01');
        $oUpdatedTo = new Date('2005-06-21 15:59:59');
        $oMaxDalForecasting->setMaintenanceForecastingLastRunInfo($oStartDate, $oEndDate, $oUpdatedTo);
        $result = $oMaxDalForecasting->getMaintenanceForecastingLastRunInfo();
        $this->assertTrue(is_a($result, 'Date'));
        $this->assertEqual($result->format('%Y-%m-%d %H:%M:%S'), '2005-06-21 15:59:59');

        // Test 3
        $oStartDate = new Date('2005-06-21 14:00:01');
        $oEndDate   = new Date('2005-06-21 14:01:01');
        $oUpdatedTo = new Date('2005-06-21 14:59:59');
        $oMaxDalForecasting->setMaintenanceForecastingLastRunInfo($oStartDate, $oEndDate, $oUpdatedTo);
        $result = $oMaxDalForecasting->getMaintenanceForecastingLastRunInfo();
        $this->assertTrue(is_a($result, 'Date'));
        $this->assertEqual($result->format('%Y-%m-%d %H:%M:%S'), '2005-06-21 15:59:59');
        $oStartDate = new Date('2005-06-21 16:00:01');
        $oEndDate   = new Date('2005-06-21 16:01:01');
        $oUpdatedTo = new Date('2005-06-21 16:59:59');
        $oMaxDalForecasting->setMaintenanceForecastingLastRunInfo($oStartDate, $oEndDate, $oUpdatedTo);
        $result = $oMaxDalForecasting->getMaintenanceForecastingLastRunInfo();
        $this->assertTrue(is_a($result, 'Date'));
        $this->assertEqual($result->format('%Y-%m-%d %H:%M:%S'), '2005-06-21 16:59:59');

        TestEnv::rollbackTransaction();
    }

    /**
     * A method to test the getAgenciesIds method.
     */
    function testGetAgenciesIds()
    {
        $da = MAX_Dal_Forecasting::singleton();
        TestEnv::startTransaction();
        $this->generateStatsOne();
        $ret = $da->getAgenciesIds();

        $this->assertTrue(is_array($ret));
        $this->assertTrue(count($ret) == 3);
        $this->assertTrue(in_array(1, $ret));
        $this->assertTrue(in_array(2, $ret));
        $this->assertTrue(in_array(3, $ret));
        TestEnv::rollbackTransaction();
    }

    /**
     * A method to test the getAgenciesIds method.
     */
    function testGetPublishersIds()
    {
        $da = MAX_Dal_Forecasting::singleton();
        TestEnv::startTransaction();
        $this->generateStatsOne();

        $ret = $da->getPublishersIds(1);
        $this->assertTrue(is_array($ret));
        $this->assertTrue(count($ret) == 2);
        $this->assertTrue(in_array(1, $ret));
        $this->assertTrue(in_array(2, $ret));

        $ret = $da->getPublishersIds(2);
        $this->assertTrue(is_array($ret));
        $this->assertTrue(count($ret) == 1);
        $this->assertTrue(in_array(3, $ret));

        TestEnv::rollbackTransaction();
    }

    /**
     * A method to test the getAgenciesIds method.
     */
    function testGetZonesIds()
    {
        $da = MAX_Dal_Forecasting::singleton();

        TestEnv::startTransaction();
        $this->generateStatsOne();

        $ret = $da->getZonesIds(1);
        $this->assertTrue(is_array($ret));
        $this->assertTrue(count($ret) == 1);
        $this->assertTrue(in_array(1, $ret));

        $ret = $da->getZonesIds(2);
        $this->assertTrue(is_array($ret));
        $this->assertTrue(count($ret) == 2);
        $this->assertTrue(in_array(2, $ret));
        $this->assertTrue(in_array(3, $ret));

        $ret = $da->getZonesIds(3);
        $this->assertTrue(is_array($ret));
        $this->assertTrue(count($ret) == 1);
        $this->assertTrue(in_array(4, $ret));

        TestEnv::rollbackTransaction();
    }

    /**
     * A method to test the getChannelsIdsByAgencyPublisher method.
     */
    function testGetChannelsIdsByAgencyPublisher()
    {
        $da = MAX_Dal_Forecasting::singleton();
        TestEnv::startTransaction();
        $this->generateStatsOne();

        $channelAgencies = array();

        $channelAgencies[] = array(1,1);
        $channelAgencies[] = array(1,2);
        $channelAgencies[] = array(2,1);

        foreach($channelAgencies as $channelAgency) {
            list($agencyId, $publisherId) = $channelAgency;

            $ret = $da->getChannelsIdsByAgencyPublisher($agencyId, $publisherId);
            $this->assertTrue(is_array($ret));
            $this->assertTrue(count($ret) == 1);
        }

        TestEnv::rollbackTransaction();
    }

    /**
     * A method to test the getChannelsByAgencyId method.
     */
    function testGetChannelsByAgencyId()
    {
        $da = MAX_Dal_Forecasting::singleton();
        TestEnv::startTransaction();
        $this->generateStatsOne();

        $ret = $da->getChannelsByAgencyId(3);
        $this->assertTrue(is_array($ret));
        $this->assertTrue(count($ret) == 2);
        $this->assertTrue(in_array(4, $ret));
        $this->assertTrue(in_array(5, $ret));

        TestEnv::rollbackTransaction();
    }

    /**
     * A method to test the getChannelsByAgencyId method.
     *
     * Test 1: test creating split tables
     * Test 2: merging limitations with interval limitations
     * Test 3: add where for every limitation
     */
    function testBuildQueryFromLimitations()
    {
        //$da = MAX_Dal_Forecasting::singleton();

        Mock::generate('Date');
        Mock::generate('DB_QueryTool');

        Mock::generatePartial(
            'MAX_Dal_Forecasting',
            'PartialMAX_Dal_Forecasting',
            array('getIntervalLimitations'));

        $fc = new PartialMAX_Dal_Forecasting($this);
        $fc->start = new MockDate($this);
        $fc->queryBuilder = new MockDB_QueryTool($this);

        $GLOBALS['_MAX']['CONF']['table']['split'] = true;
        // Test 1
        $fc->start->expectOnce('format');
        // Test 2
        $fc->expectOnce('getIntervalLimitations');
        // Test 3
        $intervalLimitations = array(
            array('sql query', 'and'),
            array('sql query', 'and'),
        );
        $fc->setReturnValue('getIntervalLimitations', $intervalLimitations);

        $limitations = array(
            array('foo', 'and'),
            array('boo', 'and'),
            array('moo', 'and'),
        );
        $fc->queryBuilder->expectCallCount('addWhere', count($limitations) + count($intervalLimitations));

        $fc->buildQueryFromLimitations($limitations, 'foo');

        $fc->start->tally();
        $fc->tally();
    }

    /**
     * A method to test the countNumberOfRecordsInZoneBsySqlLimitations method.
     */
    function testCountNumberOfRecordsInZonesBySqlLimitations()
    {
        $da = MAX_Dal_Forecasting::singleton();
        TestEnv::startTransaction();
        $this->generateStatsTwo();

        $start = new Date('2005-08-02 10:00:00');
        $end   = new Date('2005-08-02 10:59:59');

        $ret = $da->setIntervalDates($start, $end);
        $this->assertTrue($ret);

        $sqlLimitations[] = array("zone_id = 1", 'and');
        $ret = $da->countNumberOfRecordsInZonesBySqlLimitations($sqlLimitations, 'data_raw_ad_impression');
        $this->assertEqual($ret[1], 7);

        TestEnv::rollbackTransaction();
    }

    /**
     * A method to test the countNumberOfRecordsInZoneBySqlLimitations method.
     */
    function testCountNumberOfRecordsInZoneBySqlAndPhpLimitations()
    {
        $da = MAX_Dal_Forecasting::singleton();
        TestEnv::startTransaction();
        $this->generateStatsTwo();

        $start = new Date('2005-08-02 10:00:00');
        $end   = new Date('2005-08-02 10:59:59');
        $ret = $da->setIntervalDates($start, $end);

        $phpLimitations = "phpAds_aclCheckUseragent('(Opera)', '==')";

        $this->assertTrue($ret);

        $sqlLimitations[] = array("zone_id = 1", 'and');
        $ret = $da->countNumberOfRecordsInZonesBySqlAndPhpLimitations($sqlLimitations, $phpLimitations, 'data_raw_ad_impression');
        $this->assertEqual($ret[1], 4);

        TestEnv::rollbackTransaction();
    }

    function testGetChannelLimitations()
    {
        $da = MAX_Dal_Forecasting::singleton();
        TestEnv::startTransaction();
        $this->generateStatsOne();

        $campaignId = 2;
        $wheres[] = array('banners.campaignid = '.$campaignId, 'AND');
        $joins[] = array('banners','banners.bannerid=acls.bannerid');
        $ret = $da->getChannelLimitations(1);

        $this->assertTrue(is_array($ret));
        $this->assertTrue(count($ret) == 2);
        $limit = $ret[0];
        $this->assertTrue(array_key_exists('channelid', $limit));
        $this->assertTrue(array_key_exists('logical', $limit));
        $this->assertTrue(array_key_exists('type', $limit));
        $this->assertTrue(array_key_exists('comparison', $limit));
        $this->assertTrue(array_key_exists('data', $limit));
        $this->assertTrue(array_key_exists('executionorder', $limit));

        TestEnv::rollbackTransaction();
    }

    /**
     * A method for testing the obtainPriorityLock and
     * releasePriorityLock methods.
     *
     * @TODO Complete testing using a separate client connection to
     *       ensure locking works.
     */
    function testLocking()
    {
        $dbh = &MAX_DB::singleton();
        $oDal = MAX_Dal_Forecasting::singleton();
        // Try to get the lock
        $result = $oDal->obtainForecastingLock();
        $this->assertTrue($result);
        // Try to get the lock again, with a brand new connection,
        // and ensure that the lock is NOT obtained

        // Release the lock
        $result = $oDal->releaseForecastingLock();
        $this->assertTrue($result);
    }

    function _insertChannelSummaryData()
    {
        $oDal = MAX_Dal_Forecasting::singleton();

        $start = new Date('2005-08-02 10:00:00');
        $end   = new Date('2005-08-02 10:59:59');
        $oDal->setIntervalDates($start, $end);

        $ret = $oDal->saveChannelSummary(1, 1, 'impressions', 666);
        $this->assertTrue($ret);

        $ret = $oDal->saveChannelSummary(1, 2, 'impressions', 666);
        $this->assertTrue($ret);

        $ret = $oDal->saveChannelSummary(1, 1, 'clicks', 13);
        $this->assertTrue($ret);
    }

    /**
     * A method for testing saving channel summary (storing impressions/clicks/etc in zone/channel)
     */
    function testSaveChannelSummary()
    {
        $this->_insertChannelSummaryData();

        // Check data
        $dbh = &MAX_DB::singleton();
        $conf = $GLOBALS['_MAX']['CONF'];

        $ret = $dbh->getAll("SELECT * FROM {$conf['table']['prefix']}{$conf['table']['data_summary_channel_hourly']}");
        $this->assertTrue(is_array($ret));
        $summary = $ret[0];
        $this->assertEqual($summary['impressions'], 666);
        $this->assertEqual($summary['clicks'], 13);

        $summary = $ret[1];
        $this->assertEqual($summary['impressions'], 666);
    }

    /**
     * A method for testing getting channel summary data (stored impressions/clicks/etc in zone/channel)
     */
    function testGetChannelSummary()
    {
        $this->_insertChannelSummaryData();

        $startDate = '2005-08-02 10:00:00';
        $endDate = '2005-08-02 10:59:59';

        $oDal = MAX_Dal_Forecasting::singleton();
        $ret = $oDal->getChannelSummary(1, 1, $startDate, $endDate);
        $this->assertTrue(is_array($ret));
        $this->assertEqual($ret[0]['impressions'], 666);
        $this->assertEqual($ret[0]['clicks'], 13);

        $ret = $oDal->getChannelSummary(1, 2, $startDate, $endDate);
        $this->assertTrue(is_array($ret));
        $this->assertEqual($ret[0]['impressions'], 666);
    }

    /**
     * A method for testing getting channel summary data (stored impressions/clicks/etc in zone/channel)
     */
    function testGetChannelSummaryForZones()
    {
        $this->_insertChannelSummaryData();

        $startDate = '2005-08-02 10:00:00';
        $endDate = '2005-08-02 10:59:59';

        $oDal = MAX_Dal_Forecasting::singleton();

        $ret = $oDal->getChannelSummaryForZones(1, array(1, 2), $startDate, $endDate);

        $this->assertTrue(is_array($ret));
        $this->assertEqual($ret[$startDate]['impressions'], 666 + 666);
        $this->assertEqual($ret[$startDate]['clicks'], 13);
    }

    /**
     * A method for testing getting zones ids linked to ad
     */
    function testGetPubslihersAndZonesIdsByAdId()
    {
        TestEnv::startTransaction();

        $this->generateStatsOne();
        //  add ad_zone_assoc record
        $conf = $GLOBALS['_MAX']['CONF'];
        $zonesAssocTable = $conf['table']['prefix'] . 'ad_zone_assoc';
        $sql = "INSERT INTO $zonesAssocTable VALUES (2, 2, 1, '0', 1)";
        $dbh = &MAX_DB::singleton();
        $result = $dbh->query($sql);

        $oDal = MAX_Dal_Forecasting::singleton();
        $ret = $oDal->getPubslihersAndZonesIdsByAdId(1);

        $this->assertTrue(in_array(1, $ret['publishers']));
        $this->assertTrue(in_array(2, $ret['publishers']));

        $this->assertTrue(in_array(1, $ret['zones']));
        $this->assertTrue(in_array(2, $ret['zones']));

        $ret = $oDal->getPublishersIdsByAdId(1);
        $this->assertTrue(in_array(1, $ret));
        $this->assertTrue(in_array(2, $ret));

        $ret = $oDal->getZonesIdsByAdId(1);
        $this->assertTrue(in_array(1, $ret));
        $this->assertTrue(in_array(2, $ret));

        TestEnv::rollbackTransaction();
    }

    /**
     * A method for testing getting campaign id linked to ad
     */
    function testGetCampaignByAdId()
    {
        TestEnv::startTransaction();

        $this->generateStatsOne();

        $oDal = MAX_Dal_Forecasting::singleton();
        $ret = $oDal->getCampaignByAdId(1);

        $this->assertTrue(is_array($ret));
        $this->assertEqual(4, $ret['campaignid']);

        TestEnv::rollbackTransaction();
    }

    /**
     * A method for testing getting campaign id linked to ad
     */
    function testGetAdChannelsIds()
    {
        TestEnv::startTransaction();

        $this->generateStatsOne();

        // Add channels limitations
        $dbh = &MAX_DB::singleton();
        $conf = $GLOBALS['_MAX']['CONF'];

        $aclsChannelsTable = $conf['table']['prefix'] . 'acls';
        $sql = "INSERT INTO $aclsChannelsTable (bannerid, logical, type, comparison, data, executionorder) VALUES (1, 'and', 'channel', '==', '1', 0)";
        $dbh->query($sql);
        $sql = "INSERT INTO $aclsChannelsTable (bannerid, logical, type, comparison, data, executionorder) VALUES (1, 'and', 'channel', '==', '2', 1)";
        $dbh->query($sql);

        $oDal = MAX_Dal_Forecasting::singleton();
        $ret = $oDal->getAdChannelsIds(1);

        $this->assertTrue(is_array($ret));
        $this->assertTrue(in_array(1, $ret));
        $this->assertTrue(in_array(2, $ret));

        TestEnv::rollbackTransaction();
    }

    /**
     * A method for testing getting available channels for agency/affiliates
     */
    function testGetAvailableChannelsByAgencyAndAffiliates()
    {
        TestEnv::startTransaction();

        $this->generateStatsOne();

        $oDal = MAX_Dal_Forecasting::singleton();

        $ret = $oDal->getAvailableChannelsByAgencyAndAffiliates(1, array(1,2));
        $this->assertTrue(is_array($ret));
        $this->assertTrue(in_array(1, $ret));
        $this->assertTrue(in_array(2, $ret));

        $ret = $oDal->getAvailableChannelsByAgencyAndAffiliates(3, array(1,2));
        $this->assertTrue(is_array($ret));
        $this->assertTrue(in_array(4, $ret));
        $this->assertTrue(in_array(5, $ret));

        TestEnv::rollbackTransaction();
    }

    /**
     * A method to generate data for testing.
     *
     * @access public
     */
    function generateStatsOne()
    {
        $conf = $GLOBALS['_MAX']['CONF'];
        $dbh = &MAX_DB::singleton();

        $this->agenciesCount = 3;
        $this->publishersCount = 4;
        $this->channelsCount = 5;

        // Populate campaigns table
        $campaignsTable = $conf['table']['prefix'] . 'campaigns';
        $sql = "
            INSERT INTO
                $campaignsTable
                    (
                        campaignid,
                        campaignname,
                        clientid,
                        views,
                        clicks,
                        conversions,
                        expire,
                        activate,
                        active,
                        priority,
                        weight,
                        target_impression,
                        optimise,
                        anonymous
                    )
                VALUES
                    (
                        4,
                        'test campaign',
                        1,
                        500,
                        0,
                        401,
                        '0000-00-00',
                        '0000-00-00',
                        't',
                        '4',
                        2,
                        0,
                        'f',
                        'f'
                    )";
        $result = $dbh->query($sql);

        // Add a banner
        $bannersTable = $conf['table']['prefix'] . 'banners';
        $sql = "
            INSERT INTO
                $bannersTable
                    (
                        bannerid,
                        campaignid,
                        active,
                        contenttype,
                        pluginversion,
                        storagetype,
                        filename,
                        imageurl,
                        htmltemplate,
                        htmlcache,
                        width,
                        height,
                        weight,
                        seq,
                        target,
                        url,
                        alt,
                        status,
                        bannertext,
                        description,
                        autohtml,
                        adserver,
                        block,
                        capping,
                        session_capping,
                        compiledlimitation,
                        append,
                        appendtype,
                        bannertype,
                        alt_filename,
                        alt_imageurl,
                        alt_contenttype
                    )
                VALUES
                    (
                        1,
                        4,
                        't',
                        'txt',
                        0,
                        'txt',
                        '',
                        '',
                        '',
                        '',
                        0,
                        0,
                        1,
                        0,
                        '',
                        'http://exapmle.com',
                        '',
                        'asdf',
                        'tyerterty',
                        '',
                        'f',
                        '',
                        0,
                        0,
                        0,
                        'phpAds_aclCheckDate(\'20050502\', \'!=\') and phpAds_aclCheckClientIP(\'2.22.22.2\', \'!=\') and phpAds_aclCheckLanguage(\'(sq)|(eu)|(fo)|(fi)\', \'!=\')',
                        '',
                        0,
                        0,
                        '',
                        '',
                        ''
                    )";
        $result = $dbh->query($sql);

        // Add an agency record
        $agencyTable = $conf['table']['prefix'] . 'agency';
        $sql = "
            INSERT INTO
                $agencyTable
                    (
                        agencyid,
                        name,
                        contact,
                        email,
                        username,
                        password,
                        permissions,
                        language,
                        logout_url,
                        active
                    )
                VALUES
                    (
                        1,
                        'test agency',
                        'sdfsdfsdf',
                        'example@example.com',
                        'Agency name',
                        'passwd',
                        0,
                        'en_GB',
                        'logout.php',
                        1
                    )";
        $result = $dbh->query($sql);

        $agencyTable = $conf['table']['prefix'] . 'agency';
        $sql = "
            INSERT INTO
                $agencyTable
                    (
                        agencyid,
                        name,
                        contact,
                        email,
                        username,
                        password,
                        permissions,
                        language,
                        logout_url,
                        active
                    )
                VALUES
                    (
                        2,
                        'test agency',
                        'sdfsdfsdf',
                        'example@example.com',
                        'Agency name',
                        'passwd',
                        0,
                        'en_GB',
                        'logout.php',
                        1
                    )";
        $result = $dbh->query($sql);

        $agencyTable = $conf['table']['prefix'] . 'agency';
        $sql = "
            INSERT INTO
                $agencyTable
                    (
                        agencyid,
                        name,
                        contact,
                        email,
                        username,
                        password,
                        permissions,
                        language,
                        logout_url,
                        active
                    )
                VALUES
                    (
                        3,
                        'test agency',
                        'sdfsdfsdf',
                        'example@example.com',
                        'Agency name',
                        'passwd',
                        0,
                        'en_GB',
                        'logout.php',
                        1
                    )";
        $result = $dbh->query($sql);

        // Add a client record (advertiser)
        $clientsTable = $conf['table']['prefix'] . 'clients';
        $sql = "
            INSERT INTO
                $clientsTable
                    (
                        clientid,
                        agencyid,
                        clientname,
                        contact,
                        email,
                        clientusername,
                        clientpassword,
                        permissions,
                        language,
                        report,
                        reportinterval,
                        reportlastdate,
                        reportdeactivate
                    )
                VALUES
                    (
                        1,
                        1,
                        'test client',
                        'yes',
                        'example@example.com',
                        'Agency name',
                        '',
                        59,
                        '',
                        't',
                        7,
                        '2005-03-21',
                        't'
                    )";
        $result = $dbh->query($sql);

        // Add an affiliate (publisher) record
        $publisherTable = $conf['table']['prefix'] . 'affiliates';
        $sql = "
            INSERT INTO
                $publisherTable
                (
                    affiliateid,
                    agencyid,
                    name,
                    mnemonic,
                    contact,
                    email,
                    website,
                    username,
                    password,
                    permissions,
                    language,
                    publiczones
                )
            VALUES
                (
                    1,
                    1,
                    'test publisher',
                    'ABC',
                    'foo bar',
                    'foo@example.com',
                    'www.example.com',
                    'foo',
                    'bar',
                    NULL,
                    NULL,
                    'f'
                )";
        $result = $dbh->query($sql);

        // Add an affiliate (publisher) record
        $publisherTable = $conf['table']['prefix'] . 'affiliates';
        $sql = "
            INSERT INTO
                $publisherTable
                (
                    affiliateid,
                    agencyid,
                    name,
                    mnemonic,
                    contact,
                    email,
                    website,
                    username,
                    password,
                    permissions,
                    language,
                    publiczones
                )
            VALUES
                (
                    2,
                    1,
                    'test publisher',
                    'ABC',
                    'foo bar',
                    'foo@example.com',
                    'www.example.com',
                    'foo',
                    'bar',
                    NULL,
                    NULL,
                    'f'
                )";
        $result = $dbh->query($sql);

        // Add an affiliate (publisher) record
        $publisherTable = $conf['table']['prefix'] . 'affiliates';
        $sql = "
            INSERT INTO
                $publisherTable
                (
                    affiliateid,
                    agencyid,
                    name,
                    mnemonic,
                    contact,
                    email,
                    website,
                    username,
                    password,
                    permissions,
                    language,
                    publiczones
                )
            VALUES
                (
                    3,
                    2,
                    'test publisher',
                    'ABC',
                    'foo bar',
                    'foo@example.com',
                    'www.example.com',
                    'foo',
                    'bar',
                    NULL,
                    NULL,
                    'f'
                 )";
        $result = $dbh->query($sql);

        // Add zone records
        $zonesTable = $conf['table']['prefix'] . 'zones';
        $sql = "
            INSERT INTO
                $zonesTable
                (
                    zoneid,
                    affiliateid,
                    zonename,
                    description,
                    delivery,
                    zonetype,
                    category,
                    width,
                    height,
                    ad_selection,
                    chain,
                    prepend,
                    append,
                    appendtype,
                    forceappend,
                    inventory_forecast_type
                )
            VALUES
                (
                    1,
                    1,
                    'Zone name - Default',
                    '',
                    0,
                    3,
                    '',
                    728,
                    90,
                    '',
                    '',
                    '',
                    '',
                    0,
                    'f',
                    0
                )";
        $result = $dbh->query($sql);
        $zonesTable = $conf['table']['prefix'] . 'zones';
        $sql = "
            INSERT INTO
                $zonesTable
                (
                    zoneid,
                    affiliateid,
                    zonename,
                    description,
                    delivery,
                    zonetype,
                    category,
                    width,
                    height,
                    ad_selection,
                    chain,
                    prepend,
                    append,
                    appendtype,
                    forceappend,
                    inventory_forecast_type
                )
            VALUES
                (
                    2,
                    2,
                    'Zone name - Default',
                    '',
                    0,
                    3,
                    '',
                    728,
                    90,
                    '',
                    '',
                    '',
                    '',
                    0,
                    'f',
                    0
                )";
        $result = $dbh->query($sql);
        $zonesTable = $conf['table']['prefix'] . 'zones';
        $sql = "
            INSERT INTO
                $zonesTable
                (
                    zoneid,
                    affiliateid,
                    zonename,
                    description,
                    delivery,
                    zonetype,
                    category,
                    width,
                    height,
                    ad_selection,
                    chain,
                    prepend,
                    append,
                    appendtype,
                    forceappend,
                    inventory_forecast_type
                )
            VALUES
                (
                    3,
                    2,
                    'Zone name - Default',
                    '',
                    0,
                    3,
                    '',
                    728,
                    90,
                    '',
                    '',
                    '',
                    '',
                    0,
                    'f',
                    0
                )";
        $result = $dbh->query($sql);
        $zonesTable = $conf['table']['prefix'] . 'zones';
        $sql = "
            INSERT INTO
                $zonesTable
                (
                    zoneid,
                    affiliateid,
                    zonename,
                    description,
                    delivery,
                    zonetype,
                    category,
                    width,
                    height,
                    ad_selection,
                    chain,
                    prepend,
                    append,
                    appendtype,
                    forceappend,
                    inventory_forecast_type
                )
            VALUES
                (
                    4,
                    3,
                    'Zone name - Default',
                    '',
                    0,
                    3,
                    '',
                    728,
                    90,
                    '',
                    '',
                    '',
                    '',
                    0,
                    'f',
                    0
                )";
        $result = $dbh->query($sql);

        // Add channels records
        $channelsTable = $conf['table']['prefix'] . 'channel';
        $sql = "
            INSERT INTO
                $channelsTable
                (
                    channelid,
                    agencyid,
                    affiliateid,
                    name,
                    description
                )
            VALUES
                ('1', '1', '1', 'Channel name', '')";
        $result = $dbh->query($sql);
        $sql = "
            INSERT INTO
                $channelsTable
                (
                    channelid,
                    agencyid,
                    affiliateid,
                    name,
                    description
                )
            VALUES
                ('2', '1', '2', 'Channel name', '')";
        $result = $dbh->query($sql);
        $sql = "
            INSERT INTO
                $channelsTable
                (
                    channelid,
                    agencyid,
                    affiliateid,
                    name,
                    description
                )
            VALUES
                ('3', '2', '1', 'Channel name', '')";
        $result = $dbh->query($sql);
        $sql = "
            INSERT INTO
                $channelsTable
                (
                    channelid,
                    agencyid,
                    affiliateid,
                    name,
                    description
                )
            VALUES
                ('4', '3', '0', 'Channel name', '')";
        $result = $dbh->query($sql);
        $sql = "
            INSERT INTO
                $channelsTable
                (
                    channelid,
                    agencyid,
                    affiliateid,
                    name,
                    description
                )
            VALUES
                ('5', '3', '0', 'Channel name', '')";
        $result = $dbh->query($sql);

        // Add channels limitations
        $aclsChannelsTable = $conf['table']['prefix'] . 'acls_channel';
        $sql = "INSERT INTO $aclsChannelsTable (channelid, logical, type, comparison, data, executionorder) VALUES (1, 'and', 'weekday', '==', '1,5', 0)";
        $dbh->query($sql);
        $aclsChannelsTable = $conf['table']['prefix'] . 'acls_channel';
        $sql = "INSERT INTO $aclsChannelsTable (channelid, logical, type, comparison, data, executionorder) VALUES (1, 'and', 'source', '==', 'joe', 1)";
        $dbh->query($sql);

        // Add ad_zone_assoc record
        $zonesAssocTable = $conf['table']['prefix'] . 'ad_zone_assoc';
        $sql = "INSERT INTO $zonesAssocTable VALUES (1, 1, 1, '0', 1)";
        $result = $dbh->query($sql);
    }

    /**
     * A method to generate data for testing - insert data into raw table
     *
     * @access public
     */
    function generateStatsTwo()
    {
        $conf = $GLOBALS['_MAX']['CONF'];
        $dbh = &MAX_DB::singleton();

        $tables = MAX_Table_Core::singleton();
        $GLOBALS['_MAX']['CONF']['table']['split'] = true;

        $dataDate = new Date('2005-08-02 09:28:24');
        $tables->createTable('data_raw_ad_impression', $dataDate);
        $tables->createTable('data_raw_ad_click', $dataDate);
        $tables->createTable('data_raw_ad_conversion', $dataDate);

        //  populate campaigns table
        $rawAdImpressionTable = $conf['table']['prefix'] . 'data_raw_ad_impression';
        if ($GLOBALS['_MAX']['CONF']['table']['split']) {
            $rawAdImpressionTable .= '_' . $dataDate->format('%Y%m%d');
        }

        // Insert 10 records
        // 8 records between 10 and 11
        // 9 in zone 1, 1 in zone 2
        // 4 for Opera browser

        $sql = "INSERT INTO $rawAdImpressionTable
            (viewer_id, viewer_session_id, date_time, ad_id, creative_id, zone_id, channel, language, ip_address, host_name, country, https, domain, page, query, referer, search_term, user_agent, os, browser, max_https)
            VALUES ('357826bf941721cb697a032a3d31a969', '', '2005-08-02 09:28:24', 2, 0, 1, '', 'en-us,en;q=0.5', '127.0.0.1', '127.0.0.1', 'uk', 0, 'localhost', '/channelforecasting/zone.html', '', '', '', 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.10) Gecko/20050720 Fedora/1.0.6-1.1.fc3 Firefox/1.0.6', '', '', 0);
         ";
        $dbh->query($sql);

        $sql = "INSERT INTO $rawAdImpressionTable
            (viewer_id, viewer_session_id, date_time, ad_id, creative_id, zone_id, channel, language, ip_address, host_name, country, https, domain, page, query, referer, search_term, user_agent, os, browser, max_https)
            VALUES ('357826bf941721cb697a032a3d31a969', '', '2005-08-02 10:28:25', 2, 0, 1, '', 'en-us,en;q=0.5', '127.0.0.1', '127.0.0.1', 'uk', 0, 'localhost', '/channelforecasting/zone.html', '', '', '', 'Opera/8.0 (X11; Linux i686; U; en)', '', '', 0);
         ";
        $dbh->query($sql);

        $sql = "INSERT INTO $rawAdImpressionTable
            (viewer_id, viewer_session_id, date_time, ad_id, creative_id, zone_id, channel, language, ip_address, host_name, country, https, domain, page, query, referer, search_term, user_agent, os, browser, max_https)
            VALUES ('357826bf941721cb697a032a3d31a969', '', '2005-08-02 10:28:33', 2, 0, 1, '', 'en-us,en;q=0.5', '127.0.0.1', '127.0.0.1', 'uk', 0, 'localhost', '/channelforecasting/zone.html', '', '', '', 'Opera/8.0 (X11; Linux i686; U; en)', '', '', 0);
         ";
        $dbh->query($sql);

        $sql = "INSERT INTO $rawAdImpressionTable
            (viewer_id, viewer_session_id, date_time, ad_id, creative_id, zone_id, channel, language, ip_address, host_name, country, https, domain, page, query, referer, search_term, user_agent, os, browser, max_https)
            VALUES ('357826bf941721cb697a032a3d31a969', '', '2005-08-02 10:28:43', 2, 0, 1, '', 'en-us,en;q=0.5', '127.0.0.1', '127.0.0.1', 'uk', 0, 'localhost', '/channelforecasting/zone.html', '', '', '', 'Opera/8.0 (X11; Linux i686; U; en)', '', '', 0);
         ";
        $dbh->query($sql);

        $sql = "INSERT INTO $rawAdImpressionTable
            (viewer_id, viewer_session_id, date_time, ad_id, creative_id, zone_id, channel, language, ip_address, host_name, country, https, domain, page, query, referer, search_term, user_agent, os, browser, max_https)
            VALUES ('357826bf941721cb697a032a3d31a969', '', '2005-08-02 10:28:44', 2, 0, 1, '', 'en-us,en;q=0.5', '127.0.0.1', '127.0.0.1', 'pl', 0, 'localhost', '/channelforecasting/zone.html', '', '', '', 'Opera/8.0 (X11; Linux i686; U; en)', '', '', 0);
         ";
        $dbh->query($sql);

        $sql = "INSERT INTO $rawAdImpressionTable
            (viewer_id, viewer_session_id, date_time, ad_id, creative_id, zone_id, channel, language, ip_address, host_name, country, https, domain, page, query, referer, search_term, user_agent, os, browser, max_https)
            VALUES ('f1b3e9c6cf2c3886f02d5b354ea1d9e6', '', '2005-08-02 10:29:21', 2, 0, 1, '', 'en-us,en;q=0.5', '127.0.0.1', '127.0.0.1', 'pl', 0, '', '', '', '', '', 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.10) Gecko/20050719 Fedora/1.7.10-1.3.1', '', '', 0);
         ";
        $dbh->query($sql);

        $sql = "INSERT INTO $rawAdImpressionTable
            (viewer_id, viewer_session_id, date_time, ad_id, creative_id, zone_id, channel, language, ip_address, host_name, country, https, domain, page, query, referer, search_term, user_agent, os, browser, max_https)
            VALUES ('357826bf941721cb697a032a3d31a969', '', '2005-08-02 10:30:06', 2, 0, 1, '', 'en-us,en;q=0.5', '127.0.0.1', '127.0.0.1', '', 0, 'localhost', '/channelforecasting/zone.html', '', '', '', 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.10) Gecko/20050720 Fedora/1.0.6-1.1.fc3 Firefox/1.0.6', '', '', 0);
         ";
        $dbh->query($sql);

        $sql = "INSERT INTO $rawAdImpressionTable
            (viewer_id, viewer_session_id, date_time, ad_id, creative_id, zone_id, channel, language, ip_address, host_name, country, https, domain, page, query, referer, search_term, user_agent, os, browser, max_https)
            VALUES ('357826bf941721cb697a032a3d31a969', '', '2005-08-02 10:30:08', 2, 0, 1, '', 'en-us,en;q=0.5', '127.0.0.1', '127.0.0.1', '', 0, 'localhost', '/channelforecasting/zone.html', '', '', '', 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.10) Gecko/20050720 Fedora/1.0.6-1.1.fc3 Firefox/1.0.6', '', '', 0);
         ";
        $dbh->query($sql);

        $sql = "INSERT INTO $rawAdImpressionTable
            (viewer_id, viewer_session_id, date_time, ad_id, creative_id, zone_id, channel, language, ip_address, host_name, country, https, domain, page, query, referer, search_term, user_agent, os, browser, max_https)
            VALUES ('357826bf941721cb697a032a3d31a969', '', '2005-08-02 10:30:14', 2, 0, 2, '', 'en-us,en;q=0.5', '127.0.0.1', '127.0.0.1', '', 0, 'localhost', '/channelforecasting/zone.html', '', '', '', 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.10) Gecko/20050720 Fedora/1.0.6-1.1.fc3 Firefox/1.0.6', '', '', 0);
         ";
        $dbh->query($sql);

        $sql = "INSERT INTO $rawAdImpressionTable
            (viewer_id, viewer_session_id, date_time, ad_id, creative_id, zone_id, channel, language, ip_address, host_name, country, https, domain, page, query, referer, search_term, user_agent, os, browser, max_https)
            VALUES ('f1b3e9c6cf2c3886f02d5b354ea1d9e6', '', '2005-08-02 11:30:45', 2, 0, 1, '', 'en-us,en;q=0.5', '127.0.0.1', '127.0.0.1', '', 0, '', '', '', '', '', 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.7.10) Gecko/20050719 Fedora/1.7.10-1.3.1', '', '', 0);
         ";
        $dbh->query($sql);
    }


}

?>
